<?php

namespace Eform\Instruction\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Eform\Instruction\Actions\InstructionCategoryAction;
use Eform\Instruction\Http\Requests\InstructionCategoryActionRequest;
use Eform\Instruction\Http\Resources\InstructionCategoryResource;
use Eform\Instruction\Models\InstructionCategory;

/**
 * Admin web controller class.
 */
class InstructionCategoryActionController extends BaseController
{

    /**
     * Action controller function for instruction_category.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InstructionCategoryActionRequest $request, InstructionCategory $instruction_category, $action)
    {
        try {
            $request = $request->all();
            $instruction_category = InstructionCategoryAction::run($action, $instruction_category, $request);

            $data = new InstructionCategoryResource($instruction_category);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('instruction::instruction_category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('instruction/instruction_category/' . $instruction_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('instruction/instruction_category/' . $instruction_category->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
