<?php

namespace Eform\Instruction\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Eform\Instruction\Forms\InstructionCategory as InstructionCategoryForm;
use Eform\Instruction\Http\Requests\InstructionCategoryResourceRequest;
use Eform\Instruction\Http\Resources\InstructionCategoryResource;
use Eform\Instruction\Http\Resources\InstructionCategoriesCollection;
use Eform\Instruction\Models\InstructionCategory;
use Eform\Instruction\Actions\InstructionCategoryAction;
use Eform\Instruction\Actions\InstructionCategoryActions;


/**
 * Resource controller class for instruction_category.
 */
class InstructionCategoryResourceController extends BaseController
{

    /**
     * Initialize instruction_category resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->middleware(function ($request, $next) {
            $this->form = InstructionCategoryForm::grouped(false)
                            ->setAttributes()
                            ->toArray();
            $this->modules = $this->modules(config('eform.instruction.modules'), 'instruction', guard_url('instruction'));
            return $next($request);
        });
    }

    /**
     * Display a list of instruction_category.
     *
     * @return Response
     */
    public function index(InstructionCategoryResourceRequest $request)
    {
        $request = $request->all();
        $page = InstructionCategoryActions::run('paginate', $request);

        $data = new InstructionCategoriesCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('instruction::instruction_category.names'))
            ->view('instruction::instruction_category.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display instruction_category.
     *
     * @param Request $request
     * @param Model   $instruction_category
     *
     * @return Response
     */
    public function show(InstructionCategoryResourceRequest $request, InstructionCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new InstructionCategoryResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('instruction::instruction_category.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('instruction::instruction_category.show')
            ->output();
    }

    /**
     * Show the form for creating a new instruction_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(InstructionCategoryResourceRequest $request, InstructionCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new InstructionCategoryResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('instruction::instruction_category.name'))
            ->view('instruction::instruction_category.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new instruction_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(InstructionCategoryResourceRequest $request, InstructionCategory $model)
    {
        try {
            $request = $request->all();
            $model = InstructionCategoryAction::run('store', $model, $request);
            $data = new InstructionCategoryResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('instruction::instruction_category.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('instruction/instruction_category/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/instruction/instruction_category'))
                ->redirect();
        }

    }

    /**
     * Show instruction_category for editing.
     *
     * @param Request $request
     * @param Model   $instruction_category
     *
     * @return Response
     */
    public function edit(InstructionCategoryResourceRequest $request, InstructionCategory $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new InstructionCategoryResource($model);
        // return view('instruction::instruction_category.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('instruction::instruction_category.name'))
            ->view('instruction::instruction_category.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the instruction_category.
     *
     * @param Request $request
     * @param Model   $instruction_category
     *
     * @return Response
     */
    public function update(InstructionCategoryResourceRequest $request, InstructionCategory $model)
    {
        try {
            $request = $request->all();
            $model = InstructionCategoryAction::run('update', $model, $request);
            $data = new InstructionCategoryResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('instruction::instruction_category.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('instruction/instruction_category/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('instruction/instruction_category/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the instruction_category.
     *
     * @param Model   $instruction_category
     *
     * @return Response
     */
    public function destroy(InstructionCategoryResourceRequest $request, InstructionCategory $model)
    {
        try {

            $request = $request->all();
            $model = InstructionCategoryAction::run('destroy', $model, $request);
            $data = new InstructionCategoryResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('instruction::instruction_category.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('instruction/instruction_category/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('instruction/instruction_category/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
