<?php

namespace Eform\Instruction\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Eform\Instruction\Actions\InstructionsExim;
use Eform\Instruction\Http\Requests\InstructionsEximRequest;

/**
 * Admin web controller class.
 */
class InstructionsEximController extends BaseController
{
    /**
     * Action controller function for instructions.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InstructionsEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = InstructionsExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('instruction:instructions.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('instruction/instructions/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('instruction/instructions/' . $exim))
                ->redirect();
        }
    }
}
