<?php

namespace Eform\Instruction\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Eform\Instruction\Events\InstructionCategoryWorkflow as InstructionCategoryWorkflowEvent;
use Eform\Instruction\Notifications\InstructionCategoryWorkflow as InstructionCategoryWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class InstructionCategoryWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(InstructionCategoryWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $instruction_category is submitted.
     *
     * @param InstructionCategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(InstructionCategoryWorkflowEvent $event)
    {
        $client = $event->instruction_category->client;
        Notification::send($client, new InstructionCategoryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $instruction_category is published.
     *
     * @param InstructionCategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(InstructionCategoryWorkflowEvent $event)
    {
        $client = $event->instruction_category->client;
        Notification::send($client, new InstructionCategoryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $instruction_category is approved.
     *
     * @param InstructionCategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(InstructionCategoryWorkflowEvent $event)
    {
        $client = $event->instruction_category->client;
        Notification::send($client, new InstructionCategoryWorkflowNotification($event));
    }

    /**
     * Handles the $instruction_category workflow event as a listener.
     *
     * @param InstructionCategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(InstructionCategoryWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
